@@ -12,7 +12,7 @@ BEGIN {
     our @ISA = qw< Math::BigInt::Calc >;
 }
 
-our $VERSION = '0.5014';
+our $VERSION = '0.5015';
 
 my $MAX_EXP_F;      # the maximum possible base 10 exponent with "no integer"
 my $MAX_EXP_I;      # the maximum possible base 10 exponent with "use integer"
@@ -184,10 +184,6 @@ L<https://metacpan.org/release/Math-BigInt-FastCalc>
 
 L<http://matrix.cpantesters.org/?dist=Math-BigInt-FastCalc>
 
-=item CPAN Ratings
-
-L<https://cpanratings.perl.org/dist/Math-BigInt-FastCalc>
-
 =back
 
 =head1 LICENSE
