@@ -1,10 +1,10 @@
-package builtin 0.009;
+package builtin 0.011;
 
 use strict;
 use warnings;
 
-# All code, including &import, is implemented by always-present functions in
-# the perl interpreter itself.
+# All code, including &import and &unimport, is implemented by always-present
+# functions in the perl interpreter itself.
 # See also `builtin.c` in perl source
 
 1;
@@ -21,6 +21,7 @@ builtin - Perl pragma to import built-in utility functions
         weaken unweaken is_weak
         blessed refaddr reftype
         created_as_string created_as_number
+        stringify
         ceil floor
         indexed
         trim
@@ -28,6 +29,8 @@ builtin - Perl pragma to import built-in utility functions
         export_lexically
     );
 
+    use builtin ':5.40';  # most of the above
+
 =head1 DESCRIPTION
 
 Perl provides several utility functions in the C<builtin> package. These are
@@ -76,6 +79,31 @@ don't accidentally appear as object methods from a class.
     # Can't locate object method "true" via package "An::Object::Class"
     #   at ...
 
+Imported symbols can also be removed again by using the C<no> keyword:
+
+    use builtin 'true';
+    my $yes = true;
+
+    no builtin 'true';
+    # true() is no longer aliased from builtin
+
+=head2 Version Bundles
+
+The entire set of builtin functions that were considered non-experimental by a
+version of perl can be imported all at once, by requesting a version bundle.
+This is done by giving the perl release version (without its subversion
+suffix) after a colon character:
+
+    use builtin ':5.40';
+
+The following bundles currently exist:
+
+    Version    Includes
+    -------    --------
+
+    :5.40      true false weaken unweaken is_weak blessed refaddr reftype
+               ceil floor is_tainted trim indexed
+
 =head1 FUNCTIONS
 
 =head2 true
@@ -214,6 +242,26 @@ serialisation modules such as JSON encoders or similar situations, where
 language interoperability concerns require making a distinction between values
 that are fundamentally stringlike versus numberlike in nature.
 
+=head2 stringify
+
+    $str = stringify($val);
+
+Returns a new plain perl string that represents the given argument.
+
+When given a value that is already a string, a copy of this value is returned
+unchanged. False booleans are treated like the empty string.
+
+Numbers are turned into a decimal representation. True booleans are treated
+like the number 1.
+
+References to objects in classes that have L<overload> and define the C<"">
+overload entry will use the delegated method to provide a value here.
+
+Non-object references, or references to objects in classes without a C<"">
+overload will return a string that names the underlying container type of
+the reference, its memory address, and possibly its class name if it is an
+object.
+
 =head2 ceil
 
     $num = ceil($num);
